@@ -9,7 +9,6 @@
 #rm ./*.log
 
 TOP_DIR=`pwd`
-NS3VER=3.14.1
 NS3_DIR=$TOP_DIR/`ls -d ns-*`
 PYBINDGENV_DIR=$TOP_DIR/`ls -d pybindgen-0.*`
 NSC_DIR=$TOP_DIR/`ls -d nsc-*`
@@ -37,10 +36,10 @@ make distclean
 #clean ns3 dir
 cd $NS3_DIR
 
-rm ./doc/introspected-doxygen.h
-rm ./doc/ns3-object.txt
-rm -rf ./doc/html
-rm -rf ./doc/latex
+rm -f ./doc/introspected-doxygen.h ./doc/ns3-object.txt \
+      ./doc/doxygen.warnings.log ./doc/ns3_html_theme/static/ns3_version.js
+rm -rf ./doc/html \
+       ./doc/latex
 
 make clean -C ./doc/manual
 make clean -C ./doc/tutorial
@@ -54,7 +53,8 @@ rm ./different.pcap
 ./bindings/python/waf clean
 ./bindings/python/waf distclean
 
-rm -rf ./build
+rm -rf ./build-*
+
 find . -name '*.pyc' -exec rm {} \;
 find . -name '.waf-*' -exec rm -rf {} \;
 rm waf
